Crate redox_path
source ·Structs
- The part of a path that is sent to each scheme
- The name of a scheme
Enums
- A fully qualified Redox path
Functions
- Make a relative path absolute using an optional current working directory.
- Make a path that is relative to the root of a scheme into a full path, following the rules of
canonicalize_using_cwd.