pub fn canonicalize_using_scheme<'a>(
scheme: &str,
path: &'a str,
) -> Option<String>Expand description
Make a path that is relative to the root of a scheme into a full path,
following the rules of canonicalize_using_cwd.
Returns the Some if a valid path can be constructed, None if the scheme name is not valid or some other error occurs